@@ -16,7 +16,9 @@ BEGIN {
         STATE_INIT
         STATE_POST_INIT
         STATE_CACHED_PAGES
+        STATE_PRE_ACTION
         STATE_ACTION
+        STATE_POST_ACTION
         STATE_REDIRECT
 		STATE_DECLINED
         STATE_SET_HEADERS
@@ -39,16 +41,18 @@ use constant {
     STATE_INIT => 3,
     STATE_POST_INIT => 4,
     STATE_CACHED_PAGES => 5,
-    STATE_ACTION => 6,
-    STATE_REDIRECT => 7,
-	STATE_DECLINED => 8,
-    STATE_SET_HEADERS => 9,
-    STATE_PRE_PROCESS => 10,
-    STATE_PROCESS => 11,
-    STATE_POST_PROCESS => 12,
-    STATE_CHECK_STATUS => 13,
-    STATE_OUTPUT => 14,
-    STATE_SEND_STATUS => 15
+    STATE_PRE_ACTION => 6,
+    STATE_ACTION => 7,
+    STATE_POST_ACTION => 8,
+    STATE_REDIRECT => 9,
+	STATE_DECLINED => 10,
+    STATE_SET_HEADERS => 11,
+    STATE_PRE_PROCESS => 12,
+    STATE_PROCESS => 13,
+    STATE_POST_PROCESS => 14,
+    STATE_CHECK_STATUS => 15,
+    STATE_OUTPUT => 16,
+    STATE_SEND_STATUS => 17
 };
 
 1;
